# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-31 11:11
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='BusinessRuleModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.TextField(editable=False, unique=True, verbose_name='name')),
                ('description', models.TextField(blank=True, editable=False, verbose_name='description')),
                ('rule_data', models.TextField(verbose_name='rule data')),
                ('rules', models.TextField(verbose_name='rules')),
            ],
        ),
    ]
